require 'thor'
require 'verbs'
require 'pry'

module Verbsify
  class Builder < Thor
    include Thor::Actions

    def initialize(args = [], local_options = {}, config = {})
      super
    end

    desc 'conjugate VERB', 'Conjugates most common english verbs for all persons, tenses, standard aspects, and modern moods (with active diathesis). Standard and exceptional spelling rules are obeyed.'
    method_option :tense,     aliases: "-t", desc: "One of past, present, or future. Defaults to present."
    method_option :person,    aliases: "-p", desc: "One of first, second, or third. Defaults to third."
    method_option :plurality, aliases: "-pl", desc: "Either singular or plural. Defaults to singular."
    method_option :aspect,    aliases: "-a", desc: "One of habitual, perfect, perfective, progressive, or prospective. Defaults to habitual."
    method_option :mood,      aliases: "-m", desc: "One of indicative, imperative, or subjunctive. Defaults to indicative."
    method_option :subject,   aliases: "-s", desc: "Set this to a string to prepend the conjugated verb with it. When set to true, a standard personal pronoun will be used."
    def conjugate(*phrase)
      if phrase.count > 1
        puts "#{phrase.join(" ").verb.conjugate tense: options["tense"] && options["tense"].to_sym, 
                person: options["person"] && options["person"].to_sym, 
                plurality: options["plurality"] && options["plurality"].to_sym, 
                aspect: options["aspect"] && options["aspect"].to_sym, 
                mood: options["mood"] && options["mood"].to_sym, 
                subject: options["subject"]}"
      else
        puts "#{Verbs::Conjugator.conjugate phrase.first.to_sym, 
                tense: options["tense"] && options["tense"].to_sym, 
                person: options["person"] && options["person"].to_sym, 
                plurality: options["plurality"] && options["plurality"].to_sym, 
                aspect: options["aspect"] && options["aspect"].to_sym, 
                mood: options["mood"] && options["mood"].to_sym, 
                subject: options["subject"]}"
      end
    end
  end
end
